@@ -1,3 +1,5 @@
+import logging
+
 from local_tuya.backoff import Backoff, SequenceBackoff
 from local_tuya.device import (
     Constraint,
@@ -13,4 +15,6 @@ from local_tuya.errors import (
     LocalTuyaError,
     ResponseError,
 )
-from local_tuya.protocol import ProtocolConfig, Values
+from local_tuya.protocol import ProtocolConfig, Values, Version
+
+logging.getLogger(__name__).addHandler(logging.NullHandler())
